@@ -25,15 +25,15 @@ class Extraction:
         format = f'.{format}'
         path = re.sub(r"/", r"\\", self.directory)
         Patterns_Abstract = [r"(\\begin{abstract})(?P<Abstract>.+)(\\end{abstract})",
-                             r"(\\chapter{\\abstractname})(?P<Abstract>.+)(\\tableofcontents)",
-                             r"(\\chapter{\\abstractname})(?P<Abstract>.+)(\\microtypesetup{protrusion=false})",
-                             r"(\\chapter{Abstract})(?P<Abstract>.+)(\\tableofcontents)",
-                             r"(\\section{Abstract})(?P<Abstract>.+)(\\tableofcontents)",
-                             r"(\\RAIstudentthesisAbstract)({.*})(\\RAI)",
-                             r"(\\section{Goal})(?P<Abstract>.+)(\\renewcommand)",
-                             r"(\\addcontentsline{toc}{chapter}{Abstract})(?P<Abstract>.+)(\\cleardoublepage)",
-                             r"(\\addcontentsline{toc}{chapter}{Abstract})(?P<Abstract>.+)(\\clearemptydoublepage)",
-                             r"(\\RAIstudentthesisAbstract)(.*)(\\RAI)"]
+                             r"(\\chapter{\\abstractname})((?:(?!\btableofcontents\b).)*)(\\tableofcontents)",
+                             r"(\\chapter{\\abstractname})((?:(?!\bmicrotypesetup\b).)*)(\\microtypesetup)",
+                             r"(\\chapter{Abstract})((?:(?!\btableofcontents\b).)*)(\\tableofcontents)",
+                             r"(\\section{Abstract})((?:(?!\btableofcontents\b).)*)(\\tableofcontents)",
+                             r"(\\RAIstudentthesisAbstract)({(?:(?!\bRAI\b).)*})(\\RAI)",
+                             r"(\\section{Goal})((?:(?!\brenewcommand\b).)*)(\\renewcommand)",
+                             r"(\\addcontentsline{toc}{chapter}{Abstract})((?:(?!\bcleardoublepage\b).)*)(\\cleardoublepage)",
+                             r"(\\addcontentsline{toc}{chapter}{Abstract})((?:(?!\bclearemptydoublepage\b).)*)(\\clearemptydoublepage)",
+                             r"(\\RAIstudentthesisAbstract)((?:(?!\bRAI\b).)*)(\\RAI)"]
         Patterns_Authors = [r"(\\author)({)(?P<Authors>.+)(})",
                             r"(\\author)({)(?P<Authors>[\w\s\n\:\-\'\{\}\"\\]*)(})",
                             r"(\\newcommand{\\getAuthor})({)(?P<Authors>.+)(})",
@@ -95,6 +95,7 @@ class Extraction:
                         if Authors != []:
                             filename = filepath
                             df_all.loc[number_of_students, "Directory"] = filepath
+                            df_all.loc[number_of_students, "Authors"] = Authors[0][2].strip()
                             break
                     for pattern in Patterns_Abstract:
                         Abstract = re.findall(pattern, text.replace("\n", " "))
@@ -104,16 +105,21 @@ class Extraction:
                             if np.size(Abstract[0][1].split("\chapter{Zusammenfassung}")) == 2:
                                 df_all.loc[number_of_students, "Abstract_de"] = \
                                 Abstract[0][1].split("\chapter{Zusammenfassung}")[1].strip()
-                            if np.size(Abstract[0][1].split("\section{Inhaltsangabe}")) == 2:
+                            elif np.size(Abstract[0][1].split("\section{Inhaltsangabe}")) == 2:
                                 df_all.loc[number_of_students, "Abstract_en"] = \
                                 Abstract[0][1].split("\section{Inhaltsangabe}")[0].strip()
                                 df_all.loc[number_of_students, "Abstract_de"] = \
                                 Abstract[0][1].split("\section{Inhaltsangabe}")[1].strip()
-                            if np.size(Abstract[0][1].split("\chapter{Inhaltsangabe}")) == 2:
+                            elif np.size(Abstract[0][1].split("\chapter{Inhaltsangabe}")) == 2:
                                 df_all.loc[number_of_students, "Abstract_en"] = \
                                 Abstract[0][1].split("\chapter{Inhaltsangabe}")[0].strip()
                                 df_all.loc[number_of_students, "Abstract_de"] = \
                                 Abstract[0][1].split("\chapter{Inhaltsangabe}")[1].strip()
+                            elif np.size(Abstract[0][1].split("\\chapter{\\abstractname}")) == 2:
+                                df_all.loc[number_of_students, "Abstract_en"] = \
+                                Abstract[0][1].split("\\chapter{\\abstractname}")[0].strip()
+                                df_all.loc[number_of_students, "Abstract_de"] = \
+                                Abstract[0][1].split("\\chapter{\\abstractname}")[1].strip()
                             break
                     for pattern in Patterns_Title_en:
                         Title_en = re.findall(pattern, text)
@@ -149,10 +155,6 @@ class Extraction:
                         if Authors != [] and Abstract == []:
                             df_all.drop(index=number_of_students, inplace=True)
                             continue
-                        elif Authors == [] and Abstract != []:
-                            df_all.loc[number_of_students, "Directory"] = filepath
-                            df_all.loc[number_of_students, "Type"] = filepath.split("\\")[7]
-                            df_all.loc[number_of_students, "Year"] = filepath.split("\\")[8]
                         number_of_students += 1
         return df_all
 
@@ -197,14 +199,15 @@ class Extraction:
         format = f'.{format}'
         path = re.sub(r"/", r"\\", self.directory)
         Patterns_Abstract = [r"(\\begin{abstract})(?P<Abstract>.+)(\\end{abstract})",
-                             r"(\\chapter{\\abstractname})(?P<Abstract>.+)(\\microtypesetup)",
-                             r"(\\chapter{Abstract})(?P<Abstract>.+)(\\tableofcontents)",
-                             r"(\\section{Abstract})(?P<Abstract>.+)(\\tableofcontents)",
-                             r"(\\RAIstudentthesisAbstract)({.*})(\\RAI)",
-                             r"(\\section{Goal})(?P<Abstract>.+)(\\renewcommand)",
-                             r"(\\addcontentsline{toc}{chapter}{Abstract})(?P<Abstract>.+)(\\cleardoublepage)",
-                             r"(\\addcontentsline{toc}{chapter}{Abstract})(?P<Abstract>.+)(\\clearemptydoublepage)",
-                             r"(\\RAIstudentthesisAbstract)(.*)(\\RAI)"]
+                             r"(\\chapter{\\abstractname})((?:(?!\btableofcontents\b).)*)(\\tableofcontents)",
+                             r"(\\chapter{\\abstractname})((?:(?!\bmicrotypesetup\b).)*)(\\microtypesetup)",
+                             r"(\\chapter{Abstract})((?:(?!\btableofcontents\b).)*)(\\tableofcontents)",
+                             r"(\\section{Abstract})((?:(?!\btableofcontents\b).)*)(\\tableofcontents)",
+                             r"(\\RAIstudentthesisAbstract)({(?:(?!\bRAI\b).)*})(\\RAI)",
+                             r"(\\section{Goal})((?:(?!\brenewcommand\b).)*)(\\renewcommand)",
+                             r"(\\addcontentsline{toc}{chapter}{Abstract})((?:(?!\bcleardoublepage\b).)*)(\\cleardoublepage)",
+                             r"(\\addcontentsline{toc}{chapter}{Abstract})((?:(?!\bclearemptydoublepage\b).)*)(\\clearemptydoublepage)",
+                             r"(\\RAIstudentthesisAbstract)((?:(?!\bRAI\b).)*)(\\RAI)"]
         df_Abstract = pd.DataFrame([], columns=["Directory", "Abstract_en", "Abstract_de"])
         number_of_students = 1
         for subdir, dirs, files in os.walk(path):
